pub struct ResponseError {
pub code: ResponseErrorCode,
pub error: String,
pub general_problem: Option<String>,
pub kind: String,
pub possible_fix: Option<String>,
pub requirement: Option<String>,
pub validation_errors: Option<Vec<ValidationError>>,
}Fields
code: ResponseErrorCodeClass of error that has occurred or been detected.
error: Stringgeneral_problem: Option<String>An English string with a broader/alternative description of the problem.
kind: Stringpossible_fix: Option<String>An English string with hints to the API client developer. Consider this a micro-FAQ answer specific to the particular error case. Very unlikely to be suitable for direct presentation to a user.
requirement: Option<String>An English string describing the constraint on the API that wasn’t met by the current request.
validation_errors: Option<Vec<ValidationError>>In the case where the server detected one or more errors with regard to the value of specific individual parameters, rather than with the request as a whole, the error response hash may be augmented with parameter-specific error messages. These messages are packaged in an array of hashes, stored under the validation_errors key. Each validation error hash contains a field key with the name of a request parameter (resource attribute), and a problem key with an English string describing the error(s) detected in the value of that parameter.